@@ -1,7 +1,6 @@
-#!/bin/sh
+#!/usr/bin/env bash
 if test "$1" = "" ; then
-	NVER=`$HOME/neuron/nrn/nrnversion.sh`
-	NDIR=NEURON-$NVER
+	NDIR=NEURON
 else
 	NDIR="$1"
 fi
