@@ -1,6 +1,4 @@
 #include <nrnmpiuse.h>
 #if NRNMPI
 #include "../parallel/bbssrv2mpi.cpp"
-#else
-#include "../parallel/bbslsrv2.cpp"
 #endif
