@@ -4,11 +4,8 @@
 
 #include "oc2iv.h"
 
-extern "C" {
 #include "section.h"
-}
 
 #include "ndatclas.h"
 
 #endif
-
