@@ -3,9 +3,6 @@
 
 typedef void (*NrnBBSCallback)(const char*);
 
-#if defined(__cplusplus)
-extern "C" {
-#endif
 bool nrnbbs_connect();
 void nrnbbs_disconnect();
 bool nrnbbs_connected();
@@ -25,7 +22,7 @@ void nrnbbs_exec(const char*);
 void nrnbbs_notify(const char*, NrnBBSCallback);
 
 // return when *pflag = true or one step wait if no arg
-void nrnbbs_wait(bool* pflag = (bool*)0);
+void nrnbbs_wait(bool* pflag = (bool*) 0);
 
 /* for debugging and bbs management */
 #if 0
@@ -35,7 +32,4 @@ int nrnbbs_count();
 bool nrnbbs_query(long index);
 #endif
 
-#if defined(__cplusplus)
-}
-#endif
 #endif
